@@ -35,6 +35,7 @@ from solfege import soundcard
 from solfege import abstract
 from solfege import cfg
 from solfege import dataparser
+from solfege import filesystem
 from solfege import gu
 from solfege import i18n
 from solfege import lessonfile
@@ -72,7 +73,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 20
+    rcfileversion = 21
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -155,6 +156,11 @@ def check_rcfile():
                 cfg.set_int("%s/maximum_number_of_intervals" % ex, 12)
     if cfg.get_int("app/rcfileversion") < 20:
         cfg.del_key("gui/reserved_vspace")
+    if cfg.get_int("app/rcfileversion") < 21:
+        for ex in ("melodicinterval", "harmonicinterval"):
+            i = cfg.get_int("%s/inputwidget" % ex)
+            if i > 0:
+                cfg.set_int("%s/inputwidget" % ex, i + 1)
 
     cfg.set_int("app/rcfileversion", rcfileversion)
     try:
@@ -298,12 +304,6 @@ class SolfegeApp(cfg.ConfigUtils):
                 "the preferences window.\n\n"
                 "It is also possible that the OS sound setup is incorrect."
                 % str(e).decode(locale.getpreferredencoding(), 'replace'))
-    def play_happy_sound(self):
-        utils.play_music(r"\staff\relative c'{c16 e g a}", 180, 8,
-               cfg.get_int('config/preferred_instrument_volume'))
-    def play_sad_sound(self):
-        utils.play_music(r"\staff\relative c'{<c,,8 cis>", 80, 58,
-               cfg.get_int('config/preferred_instrument_volume'))
     def please_help_me(self):
         if isinstance(solfege.win.get_view(), abstract.Gui):
             # If the view visible is an exercise, when we check if the
@@ -324,6 +324,15 @@ class SolfegeApp(cfg.ConfigUtils):
         module = lessonfile.infocache.get(filename, 'module')
         if self.m_running_exercise:
             solfege.win.box_dict[self.m_running_exercise].on_end_practise()
+        if not lessonfile.is_uri(filename):
+            # Since the file is in ~/.solfege/exercises we must check
+            # if the user have written his own exercise module
+            if os.path.exists(os.path.normpath(os.path.join(
+                            os.path.dirname(filename),
+                            "..", "modules", u"%s.py" % module))):
+                module = u"user:%s/%s" % (
+                    os.path.dirname(filename).split(os.sep)[-2],
+                    module)
         if module not in self.m_teachers:
             self.create_teacher(module)
         if module not in solfege.win.box_dict:
@@ -380,8 +389,35 @@ class SolfegeApp(cfg.ConfigUtils):
         """
         Create the teacher in 'modulename' and add it to self.m_teachers.
         """
-        m = __import__("solfege.exercises.%s" % modulename, fromlist=("solfege.exercises.%s" % modulename,), level=0)
+        m = self.import_module(modulename)
         self.m_teachers[modulename] = m.Teacher(modulename)
+    def import_module(self, modulename):
+        """
+        If prefixed with "solfege:"
+
+          user:collection/modulename
+
+        collection is the directory name in
+        ~/.solfege/exercises/collection/modulename
+        and "user:" is just a prefix to show that the module name
+        is in the users directory.
+
+        If a plain string with not prefix, it is one of the standard modules
+        included with Solfege.
+
+        Return the imported module
+        """
+        if modulename.startswith("user:"):
+            collection = modulename[len("user:"):].split(os.sep)[0]
+            module_dir = os.path.join(filesystem.user_data(),
+                                      "exercises", collection, "modules")
+            sys.path.insert(0, module_dir)
+            m = __import__(modulename.split("/")[1])
+            reload(m)
+            del sys.path[0]
+        else:
+            m = __import__("solfege.exercises.%s" % modulename, fromlist=("solfege.exercises.%s" % modulename,), level=0)
+        return m
     def reset_exercise(self, w=None):
         """
         Call on_end_practise, and then on_start_practise in
