@@ -63,8 +63,10 @@ def langs():
 def _nop(s):
     return unicode(s)
 
+
+translation = None
 def setup(prefix, config_locale=None):
-    global locale_setup_failed
+    global locale_setup_failed, translation
     # Gettext and gtk+ chech the variables in this order.
     try:
         locale.setlocale(locale.LC_ALL, '')
@@ -108,14 +110,14 @@ def setup(prefix, config_locale=None):
                 s = locale.normalize(s)
                 os.environ['LANGUAGE'] = s
     import __builtin__
-    t = gettext.translation("solfege",
+    translation = gettext.translation("solfege",
                            os.path.join(prefix, 'share', 'locale'),
                            fallback=True)
-    __builtin__.__dict__['_'] = t.ugettext
-    __builtin__.__dict__['_no_xgettext'] = t.ugettext
+    __builtin__.__dict__['_'] = translation.ugettext
+    __builtin__.__dict__['_no_xgettext'] = translation.ugettext
     __builtin__.__dict__['_i'] = _i
     __builtin__.__dict__['_i_no_xgettext'] = _i
-    __builtin__.__dict__['ungettext'] = t.ungettext
+    __builtin__.__dict__['ungettext'] = translation.ungettext
     # plurals usage:
     # i =  'some integer value'
     # ungettext("%i car", "%i cars", i) % i
